@@ -4,7 +4,7 @@ import numpy as np
 import pandas as pd
 import xarray as xr
 
-from pyplan_core import cubepy 
+from pyplan_core import cubepy
 from pyplan_core.classes.evaluators.BaseEvaluator import BaseEvaluator
 from pyplan_core.classes.common.filterChoices import filterChoices
 from pyplan_core.classes.common.indexValuesReq import IndexValuesReq
@@ -13,17 +13,15 @@ from pyplan_core.cubepy.cube import kindToString, safemax, safemean, safemin, sa
 
 class CubepyEvaluator(BaseEvaluator):
 
-    PAGESIZE = 100
     MAX_COLUMS = 5000
 
-    def evaluateNode(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0):
+    def evaluateNode(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         if isinstance(result, cubepy.Cube):
-            return self.cubeEvaluate(result, nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow)
+            return self.cubeEvaluate(result, nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow, hideEmpty)
         elif isinstance(result, cubepy.Index):
-            return self.indexEvaluate(result, nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow)
+            return self.indexEvaluate(result, nodeDic, nodeId, dims, rows, columns, summaryBy, bottomTotal, rightTotal, fromRow, toRow, hideEmpty)
 
-    def cubeEvaluate(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0):
-        result_structure = self.getStructure(result)
+    def cubeEvaluate(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         sby = safesum
         if summaryBy == 'avg':
             sby = safemean
@@ -38,7 +36,8 @@ class CubepyEvaluator(BaseEvaluator):
             toRow = 100
         fromRow = int(fromRow)
         toRow = int(toRow)
-
+        pagesize = toRow - fromRow + 1
+        
         result = self.applyHierarchy(
             result, nodeDic, nodeId, dims, rows, columns, sby)
 
@@ -140,7 +139,7 @@ class CubepyEvaluator(BaseEvaluator):
             }
         elif len(_columns) == 0:
 
-            if (len(finalIndexes) > self.PAGESIZE):
+            if (len(finalIndexes) > pagesize):
                 pageInfo = {
                     "fromRow": int(fromRow),
                     "toRow": int(toRow),
@@ -162,7 +161,7 @@ class CubepyEvaluator(BaseEvaluator):
             onColumn = _columns[0]
             onRow = _rows[0]
 
-            if (len(finalIndexes) > self.PAGESIZE):
+            if (len(finalIndexes) > pagesize):
                 pageInfo = {
                     "fromRow": int(fromRow),
                     "toRow": int(toRow),
@@ -181,7 +180,7 @@ class CubepyEvaluator(BaseEvaluator):
                 res["data"].append(
                     _totalRow[:CubepyEvaluator.MAX_COLUMS].tolist())
 
-        return self.createResult(res, result_structure, onRow=onRow, onColumn=onColumn, node=nodeDic[nodeId], pageInfo=pageInfo)
+        return self.createResult(res, onRow=onRow, onColumn=onColumn, node=nodeDic[nodeId], pageInfo=pageInfo)
 
     def applyHierarchy(self, result, nodeDic, nodeId, dims, rows, columns, sby):
 
@@ -286,9 +285,9 @@ class CubepyEvaluator(BaseEvaluator):
                     result._axes, result._values), levels, maps)
         return result
 
-    def indexEvaluate(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0):
+    def indexEvaluate(self, result, nodeDic, nodeId, dims=None, rows=None, columns=None, summaryBy="sum", bottomTotal=False, rightTotal=False, fromRow=0, toRow=0, hideEmpty=None):
         res = result.values[:100].tolist()
-        return self.createResult(res, self.getStructure(res), node=nodeDic[nodeId])
+        return self.createResult(res, node=nodeDic[nodeId])
 
     def addToFilter(self, nodeDic, dim, filters):
         if "values" in dim and dim["values"] is not None and len(dim["values"]) > 0:
@@ -383,7 +382,8 @@ class CubepyEvaluator(BaseEvaluator):
                 "isEditable": True if self.isTable(nodeDic[nodeId]) == "1" else False,
                 "nodeProperties": {
                     "title": nodeDic[nodeId].title if not nodeDic[nodeId].title is None else nodeDic[nodeId].identifier,
-                    "numberFormat": nodeDic[nodeId].numberFormat
+                    "description": nodeDic[nodeId].description,
+                    "numberFormat": nodeDic[nodeId].numberFormat,
                 }
             }
 
